@@ -256,10 +256,6 @@ class RequestsTransport(Transport):
         # xmlrpclib fails to escape \r
         request_body = request_body.replace(b'\r', b'&#xd;')
 
-        # Needed for python-requests < 2.0 with python3, otherwise we get
-        # Content-Type error later for the POST request
-        request_body = request_body.decode('utf-8')
-
         return self._request_helper(url, request_body)
 
 
@@ -384,6 +380,12 @@ class BugzillaBase(object):
 
     def __init__(self, url=None, user=None, password=None, cookiefile=-1,
                  sslverify=True, tokenfile=-1):
+        """
+        :param tokenfile: If -1, use the default path. If None, don't use
+            or save any tokenfile.
+        :param cookiefile: If -1, use the default path. If None, don't use
+            or save any cookiefile.
+        """
         # Hook to allow Bugzilla autodetection without weirdly overriding
         # __init__
         if self._init_class_from_url(url, sslverify):
@@ -483,7 +485,7 @@ class BugzillaBase(object):
     def _listify(self, val):
         if val is None:
             return val
-        if type(val) is list:
+        if isinstance(val, list):
             return val
         return [val]
 
@@ -620,8 +622,7 @@ class BugzillaBase(object):
         '''Attempt to log in using the given username and password. Subsequent
         method calls will use this username and password. Returns False if
         login fails, otherwise returns some kind of login info - typically
-        either a numeric userid, or a dict of user info. It also sets the
-        logged_in attribute to True, if successful.
+        either a numeric userid, or a dict of user info.
 
         If user is not set, the value of Bugzilla.user will be used. If *that*
         is not set, ValueError will be raised. If login fails, BugzillaError
@@ -654,27 +655,12 @@ class BugzillaBase(object):
         """
         Helper method to handle login for this bugzilla instance.
 
-        If a 'user' is provided or 'force' is set to True; or no cookie/token
-        file exists, a username/password authentication is attempted requesting
-        any information that is not available from the user.
-
-        If a cookie/token file exists, the call to the instance login method is
-        skipped.
+        :param user: bugzilla username. If not specified, prompt for it.
+        :param password: bugzilla password. If not specified, prompt for it.
+        :param force: Unused
         """
-        if not force and user is None:
-            auths = {
-                'cookies': self.cookiefile,
-                'token': self.tokenfile,
-            }
-            for (method, source) in auths.items():
-                if source and os.path.exists(source):
-                    log.info(
-                        'Using %s in %s for authentication', method, source)
-                    return
-        elif not force:
-            log.error('No authentication information provided for login')
-
-        log.info('Using username/password for authentication')
+        ignore = force
+        log.debug('Calling interactive_login')
 
         if not user:
             sys.stdout.write('Bugzilla Username: ')
@@ -801,9 +787,8 @@ class BugzillaBase(object):
         return self._components_details[product]
 
     def getcomponentdetails(self, product, component, force_refresh=False):
-        '''Get details for a single component. Returns a dict with the
-        following keys:
-        description, initialowner, initialqacontact, initialcclist'''
+        '''Get details for a single component. See bugzilla documentation
+        for a list of returned keys.'''
         d = self.getcomponentsdetails(product, force_refresh)
         return d[component]
 
@@ -814,7 +799,7 @@ class BugzillaBase(object):
         return self._components[product]
 
     def _component_data_convert(self, data, update=False):
-        if type(data['product']) is int:
+        if isinstance(data['product'], int):
             data['product'] = self._product_id_to_name(data['product'])
 
 
@@ -853,6 +838,8 @@ class BugzillaBase(object):
                                        initial QA contact
         default_cc: (optional) The initial list of users to be CC'ed on
                                new bugs for the component.
+        is_active: (optional) If False, the component is hidden from
+                              the component list when filing new bugs.
         '''
         data = data.copy()
         self._component_data_convert(data)
@@ -904,10 +891,8 @@ class BugzillaBase(object):
         if exclude_fields:
             kwargs["exclude_fields"] = exclude_fields
 
-        # The bugzilla4 name is Product.get(), but Bugzilla3 only had
-        # Product.get_product, and bz4 kept an alias.
-        log.debug("Calling Product.get_products with: %s", kwargs)
-        ret = self._proxy.Product.get_products(kwargs)
+        log.debug("Calling Product.get with: %s", kwargs)
+        ret = self._proxy.Product.get(kwargs)
         return ret['products']
 
     def _getproducts(self, **kwargs):
@@ -916,7 +901,7 @@ class BugzillaBase(object):
         return r
 
     def _getcomponents(self, product):
-        if type(product) == str:
+        if isinstance(product, str):
             product = self._product_name_to_id(product)
         r = self._proxy.Bug.legal_values({'product_id': product,
                                           'field': 'component'})
@@ -1076,6 +1061,12 @@ class BugzillaBase(object):
                 for b in self._getbugs(idlist, simple=True)]
 
 
+    def get_comments(self, idlist):
+        '''Returns a dictionary of bugs and comments.  The comments key will
+           be empty.  See bugzilla docs for details'''
+        return self._proxy.Bug.comments({'ids': idlist})
+
+
     #################
     # query methods #
     #################
@@ -1519,7 +1510,7 @@ class BugzillaBase(object):
             # BZ 4.4+
             ret = ret["ids"]
 
-        if type(ret) is list and len(ret) == 1:
+        if isinstance(ret, list) and len(ret) == 1:
             ret = ret[0]
         return ret
 
@@ -1648,7 +1639,7 @@ class BugzillaBase(object):
                                 "args=%s with kwargs=%s, must be one or the "
                                 "other." % (args, kwargs))
         if args:
-            if len(args) > 1 or type(args[0]) is not dict:
+            if len(args) > 1 or not isinstance(args[0], dict):
                 raise BugzillaError("createbug: positional arguments only "
                                     "accept a single dictionary.")
             data = args[0]
