@@ -14,6 +14,7 @@ else:
     from StringIO import StringIO
 
 
+os.environ["PYTHON_BUGZILLA_TEST_SUITE"] = "1"
 _cleanup = []
 
 
@@ -31,6 +32,9 @@ def _cleanup_cb():
 atexit.register(_cleanup_cb)
 bugzillascript = _import("bugzillascript", "bin/bugzilla")
 
+# This is overwritten by python setup.py test --redhat-url, and then
+# used in ro/rw tests
+REDHAT_URL = None
 
 
 def diff(orig, new):
