@@ -9,18 +9,20 @@
 Unit tests for building query strings with bin/bugzilla
 '''
 
+import copy
 import os
 import unittest
 
+import bugzilla
 from bugzilla.bugzilla3 import Bugzilla34
 from bugzilla.bugzilla4 import Bugzilla4
 from bugzilla.rhbugzilla import RHBugzilla4
 
 import tests
 
-bz34 = Bugzilla34(cookiefile=None)
-bz4 = Bugzilla4(cookiefile=None)
-rhbz4 = RHBugzilla4(cookiefile=None)
+bz34 = Bugzilla34(cookiefile=None, tokenfile=None)
+bz4 = Bugzilla4(cookiefile=None, tokenfile=None)
+rhbz4 = RHBugzilla4(cookiefile=None, tokenfile=None)
 
 
 class BZ34Test(unittest.TestCase):
@@ -242,6 +244,39 @@ class RHBZTest(BZ4Test):
         'component': ["lvm2", "kernel"],
         'sub_components': ["Command-line tools (RHEL5)"]}
 
+    def testTranslation(self):
+        def translate(_in):
+            _out = copy.deepcopy(_in)
+            self.bz.pre_translation(_out)
+            return _out
+
+        in_query = {
+            "fixed_in": "foo.bar",
+            "product": "some-product",
+            "cf_devel_whiteboard": "some_devel_whiteboard",
+            "include_fields": ["fixed_in",
+                "components", "cf_devel_whiteboard"],
+        }
+        out_query = translate(in_query)
+
+        in_query["include_fields"] = [
+            "cf_devel_whiteboard", "cf_fixed_in", "component"]
+        self.assertDictEqual(in_query, out_query)
+
+        in_query = {"bug_id": "123,456", "component": "foo,bar"}
+        out_query = translate(in_query)
+        self.assertEqual(out_query["id"], ["123", "456"])
+        self.assertEqual(out_query["component"], ["foo", "bar"])
+
+        in_query = {"bug_id": [123, 124], "column_list": ["id"]}
+        out_query = translate(in_query)
+        self.assertEqual(out_query["id"], [123, 124])
+        self.assertEqual(out_query["include_fields"], in_query["column_list"])
+
+    def testInvalidBoolean(self):
+        self.assertRaises(RuntimeError, self.bz.build_query,
+            boolean_query="foobar")
+
 
 class TestURLToQuery(BZ34Test):
     def _check(self, url, query):
@@ -275,3 +310,7 @@ class TestURLToQuery(BZ34Test):
             'order': 'bug_status,bug_id'
         }
         self._check(url, query)
+
+    def testBZAutoMagic(self):
+        bz = bugzilla.Bugzilla("bugzilla.redhat.com")
+        self.assertTrue(hasattr(bz, "rhbz_back_compat"))
