@@ -65,8 +65,7 @@ class RHPartnerTest(BaseTest):
     # Despite its name, this instance is simply for bugzilla testing,
     # doesn't send out emails and is blown away occasionally. The front
     # page has some info.
-    url = "https://partner-bugzilla.redhat.com/xmlrpc.cgi"
-    # url = "https://bzweb01-devel.app.eng.rdu.redhat.com/"
+    url = tests.REDHAT_URL or "https://partner-bugzilla.redhat.com/xmlrpc.cgi"
     bzclass = bugzilla.RHBugzilla
 
 
@@ -710,6 +709,7 @@ class RHPartnerTest(BaseTest):
                              compdata["default_assigned_to"])
             self.assertEqual(data["initialqacontact"],
                              compdata["default_qa_contact"])
+            self.assertEqual(data["is_active"], compdata["is_active"])
 
 
         # Create component
@@ -719,8 +719,11 @@ class RHPartnerTest(BaseTest):
             "initialowner": "crobinso@redhat.com",
             "initialqacontact": "extras-qa@fedoraproject.org",
             "initialcclist": ["wwoods@redhat.com", "toshio@fedoraproject.org"],
+            "is_active": True,
         })
         newid = bz.addcomponent(data)['id']
+        print("Created product=%s component=%s" % (
+            basedata["product"], basedata["component"]))
         compare(data, newid)
 
         # Edit component
@@ -731,6 +734,7 @@ class RHPartnerTest(BaseTest):
             "initialqacontact": "virt-mgr-maint@redhat.com",
             "initialcclist": ["libvirt-maint@redhat.com",
                               "virt-maint@lists.fedoraproject.org"],
+            "is_active": False,
         })
         bz.editcomponent(data)
         compare(data, newid)
@@ -874,3 +878,8 @@ class RHPartnerTest(BaseTest):
         bz.remove_external_tracker(ids=ids)
         ids = [bug['id'] for bug in bz.getbug(bugid).external_bugs]
         assert len(ids) == 0
+
+    def test15EnsureLoggedIn(self):
+        bz = self.bzclass(url=self.url, cookiefile=cf, tokenfile=tf)
+        comm = "bugzilla --ensure-logged-in query --bug_id 979546"
+        tests.clicomm(comm, bz)
